pub struct QueryBundle {
pub schema: QuerySchema,
pub label: String,
pub document: Option<MantDocument>,
pub tldr: Option<TldrDocument>,
}Expand description
Native result consumed by JSON, Markdown, and interactive frontends.
Fields
schema: QuerySchemalabel: Stringdocument: Option<MantDocument>tldr: Option<TldrDocument>Trait Implementations
Sourceimpl Clone for QueryBundle
impl Clone for QueryBundle
Sourcefn clone(&self) -> QueryBundle
fn clone(&self) -> QueryBundle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryBundle
impl Debug for QueryBundle
Sourceimpl<'de> Deserialize<'de> for QueryBundle
impl<'de> Deserialize<'de> for QueryBundle
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for QueryBundle
Sourceimpl JsonSchema for QueryBundle
impl JsonSchema for QueryBundle
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for QueryBundle
impl PartialEq for QueryBundle
Sourceimpl Serialize for QueryBundle
impl Serialize for QueryBundle
impl StructuralPartialEq for QueryBundle